@@ -16,7 +16,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( );
 
-our $VERSION = '0.9';
+our $VERSION = '1.0';
 
 =head1 NAME
 
@@ -369,9 +369,17 @@ Drew Stephens <drew@dinomite.net>, http://dinomite.net
 
 =head1 CONTRIBUTORS
 
-Mark Grimes <mgrimes@cpan.org>, http://www.peculiarities.com
+=over4
 
-Garrett Scott <garrett@gothik.org>, http://www.gothik.org
+=item *
+
+Mark Grimes <mgrimes@cpan.org>, L<http://www.peculiarities.com>
+
+=item *
+
+Garrett Scott <garrett@gothik.org>, L<http://www.gothik.org>
+
+=back
 
 =head1 SOURCE REPOSITORY
 
@@ -379,9 +387,7 @@ http://mac-itunes.googlecode.com
 
 =head1 SVN INFO
 
-$Revision: 86 $
-$Date: 2010-05-30 20:45:18 -0700 (Sun, 30 May 2010) $
-$Author: drewgstephens@gmail.com $
+$Revision: 90 $
 
 =head1 COPYRIGHT AND LICENSE
 
